@@ -270,7 +270,10 @@ class Selenium(Scraper):
         return image_filename
 
     def on_switch_to(self, element: any) -> None:
-        self.driver.switch_to.frame(element)
+        if element == 'default':
+            self.driver.switch_to.default_content()
+        else:
+            self.driver.switch_to.frame(element)
 
     def on_freeze(self) -> None:
         self.driver.execute_cdp_cmd('Emulation.setScriptExecutionDisabled', { 'value': True })
